@@ -222,3 +222,49 @@ def add_column_statistic(column_name, statistics):
         ],
     }
 
+
+
+class DatasetPipeline(object):
+   __slots__ = ['org', 'project', 'repository', 'dataset', 'branch', 'stages', 'comment', 'author', 'source', 'tags']
+   def __init__(self, org, project, repository, dataset, branch, stages, comment, author, source, tags):
+            self.org = org
+            self.project = project
+            self.repository = repository
+            self.dataset = dataset
+            self.branch = branch
+            self.stages = stages
+            self.comment = comment
+            self.author = author
+            self.source = source
+            self.tags = tags
+
+def create_addDatasetPipeline(pipelineMetadata_list):
+    # return {"tableMetadata": tableMetadata_list} if len(tableMetadata_list)>0 else None
+    return pipelineMetadata_list if len(pipelineMetadata_list)>0 else None
+
+def create_entry_for_addDataSetPipeline(
+    org,
+    project,
+    repository="project_data",
+    dataset="Image",
+    branch="",
+    stages={},
+    comment="",
+    author="",
+    source="",
+    tags=""
+):
+    return {
+        **({'org': org} if org is not None else {}),
+        "project": project,
+        "repository": repository,
+        "dataset": dataset,
+        "branch": branch,
+        "stages": stages,
+        "comment": comment,
+        "author": author,
+        "source": source,
+        "tags": tags
+    }
+
+
