@@ -1,4 +1,5 @@
 from datacataloglib.data_catalog_interfaces import create_addDataset, create_entry_for_addDataset,  Dataset , DatasetVersion, create_entry_for_addDataSetVersion, create_addDatasetVersion, DatasetStatistic, DatasetStatisticColumn, create_addColumnStatistics, create_entry_for_addColumnStatistics, add_column_statistic
+from datacataloglib.data_catalog_interfaces import DatasetPipeline, create_addDatasetPipeline, create_entry_for_addDataSetPipeline
 from datacataloglib.request_helper import request_post_if_has_value
 
 from typing import List
@@ -77,4 +78,21 @@ def addDatasetStatistic(url, dataset_statistic_list: List[DatasetStatistic], ext
 #                                       )])
 
 
-
+def addDatasetPipeline(url, dataset_pipeline_list: List[DatasetPipeline], extra={}):
+    return request_post_if_has_value(
+        f"{url}",
+        json=create_addDatasetPipeline([
+            create_entry_for_addDataSetPipeline(
+                item.org,
+                item.project,
+                item.repository,
+                item.dataset,
+                item.branch,
+                item.stages,
+                item.comment,
+                item.author,
+                item.source,
+                tags=item.tags
+            )
+            for item in dataset_pipeline_list
+        ]), extra=extra)
\ No newline at end of file
